@@ -6,16 +6,15 @@ use base 'Exporter';
 use File::Slurp;
 
 our @EXPORT = qw(ASTU_Wait ASTU_Read_Error_Log ASTU_Read_Access_Log
-		ASTU_Reset_Table);
-
-our $ASTU_Should_Wait = $ENV{ASTU_WAIT};
-$ENV{ASTU_WAIT} = 0;
+		ASTU_Reset_Table ASTU_Module_Dir);
 
 sub ASTU_Wait {
 	my $dir = shift || "";
-	unless ($ASTU_Should_Wait) {
+	if (!defined($ENV{ASTU_WAIT})) {
 		print STDERR "# ASTU_WAIT: no \$ENV{ASTU_WAIT} is given $dir\n";
 		goto OUT;
+	} elsif (!$ENV{ASTU_WAIT}) {
+		return;
 	}
 	print STDERR "# Test is in $dir ...\nPress ENTER to continue ...\n";
 	readline(\*STDIN);
@@ -23,12 +22,14 @@ OUT:
 	exit 1;
 }
 
+sub ASTU_Module_Dir { return "$INC[0]/../.."; }
+
 sub ASTU_Read_Error_Log {
-	return read_file($ENV{SWIT_BLIB_DIR} . "/../t/logs/error_log");
+	return read_file(ASTU_Module_Dir() . "/t/logs/error_log");
 }
 
 sub ASTU_Read_Access_Log {
-	return read_file($ENV{SWIT_BLIB_DIR} . "/../t/logs/access_log");
+	return read_file(ASTU_Module_Dir() . "/t/logs/access_log");
 }
 
 sub ASTU_Reset_Table {
