@@ -5,16 +5,16 @@ package T::DBPage::DB;
 use base 'Apache::SWIT::DB::Base';
 __PACKAGE__->set_up_table('dbp');
 
-package T::DBPage::Root;
-use base 'HTML::Tested::ClassDBI';
-use HTML::Tested qw(HTV);
-
-__PACKAGE__->ht_add_widget(HTV."::Hidden", id => cdbi_bind => 'Primary');
-__PACKAGE__->ht_add_widget(HTV."::EditBox", val => cdbi_bind => '');
-__PACKAGE__->bind_to_class_dbi("T::DBPage::DB");
-
 package T::DBPage;
 use base 'Apache::SWIT::HTPage';
+use HTML::Tested qw(HTV);
+
+sub swit_startup {
+	my $rc = shift()->ht_make_root_class('HTML::Tested::ClassDBI');
+	$rc->ht_add_widget(HTV."::Hidden", id => cdbi_bind => 'Primary');
+	$rc->ht_add_widget(HTV."::EditBox", val => cdbi_bind => '');
+	$rc->bind_to_class_dbi("T::DBPage::DB");
+}
 
 sub ht_swit_render {
 	my ($class, $r, $root) = @_;
